@@ -32,10 +32,14 @@
 #define QVM_KILL_PATH "/usr/bin/qvm-kill"
 #define KDIALOG_PATH "/usr/bin/kdialog"
 #define ZENITY_PATH "/usr/bin/zenity"
+#define QUBES_RELEASE "/etc/qubes-release"
 
 /* default width of forced colorful border */
 #define BORDER_WIDTH 2
 
+/* maximum percentage of the screen that an override_redirect window can cover */
+#define MAX_OVERRIDE_REDIRECT_PERCENTAGE 90
+
 /* this makes any X11 error fatal (i.e. cause exit(1)). This behavior was the
  * case for a long time before introducing this option, so nothing really have
  * changed  */
@@ -178,18 +182,20 @@ struct _global_handles {
     pid_t kill_on_connect;  /* pid to kill when connection to gui agent is established */
     int allow_utf8_titles;    /* allow UTF-8 chars in window title */
     int allow_fullscreen;   /* allow fullscreen windows without decoration */
+    int override_redirect_protection; /* disallow override_redirect windows to cover more than
+					 MAX_OVERRIDE_REDIRECT_PERCENTAGE percent of the screen */
     int copy_seq_mask;    /* modifiers mask for secure-copy key sequence */
     KeySym copy_seq_key;    /* key for secure-copy key sequence */
     int paste_seq_mask;    /* modifiers mask for secure-paste key sequence */
     KeySym paste_seq_key;    /* key for secure-paste key sequence */
     int qrexec_clipboard;    /* 0: use GUI protocol to fetch/put clipboard, 1: use qrexec */
     int use_kdialog;    /* use kdialog for prompts (default on KDE) or zenity (default on non-KDE) */
-    int audio_low_latency; /* set low-latency mode while starting pacat-simple-vchan */
     int prefix_titles;     /* prefix windows titles with VM name (for WM without support for _QUBES_VMNAME property) */
     enum trayicon_mode trayicon_mode; /* trayicon coloring mode */
     int trayicon_border; /* position of trayicon border - 0 - no border, 1 - at the edges, 2 - 1px from the edges */
     bool trayicon_tint_reduce_saturation; /* reduce trayicon saturation by 50% (available only for "tint" mode) */
     bool trayicon_tint_whitehack; /* replace white pixels with almost-white 0xfefefe (available only for "tint" mode) */
+    Cursor *cursors;  /* preloaded cursors (using XCreateFontCursor) */
 };
 
 typedef struct _global_handles Ghandles;
